==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbquery/sqltemplate/query_connections.sql <==
with
	inputs as (select ? as yyyymmdddate, ? as seconds_from, ? as seconds_to),
	sourcetotzutcdelta as (
		select source, ext_timezonetoutcdeltasecs(inputs.yyyymmdddate, min(agency_timezone)) as tzutcdeltasecs
		from agency join inputs on 1 = 1 group by source
	),
	timetable as (
		select
			cts.service_date,
			-- E.g. normalize from/to stop times in two ways:
			-- 1) normalize to the input date YYYYMMDD, so if a time departs at 02:00 on monday the following day;
			--    converted look like 26:00 on the previous day (since all times relative to input YYYYMMDD)
			-- 2) add the agency's associated timezone UTC delta value so that routing across agencies
			--    using different timezones functions correctly. All outuput values thus in UTC time
			--
			(cts.service_date - inputs.yyyymmdddate) * (60 * 60 * 24) + con.from_stop_time + tz.tzutcdeltasecs as from_stop_drutctime,
			(cts.service_date - inputs.yyyymmdddate) * (60 * 60 * 24) + con.to_stop_time + tz.tzutcdeltasecs as to_stop_drutctime,
			con.*
		from _cvcaltoservice cts
			join inputs on (
				-- E.g. optimization so we don't have to calculate {from,to}_stop_drutctime for *all*
				-- timetable entries (should handle both tz shifts & next day for schedule logic)
				cts.service_date between inputs.yyyymmdddate - 1 and inputs.yyyymmdddate + 1
			) and cts.source in ({{ .SourcePlaceholders }})
			join {{ .Table }} con
				on cts.service_id = con.service_id and cts.source = con.source
				and from_stop_drutctime between seconds_from and seconds_to
			join sourcetotzutcdelta tz on con.source = tz.source
			order by from_stop_drutctime asc
	)
	select {{ .Columns }} from timetable

==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/dbquery/sqltemplate/query_connections.sql <==
with
	inputs as (select ? as yyyymmdddate, ? as seconds_from, ? as seconds_to),
	tztodelta as ({{ .TzToDeltaSubquery }}),
	feedidtotzutcdelta as (
		-- Note: re distinct, per GTFS spec; if there is >1 agency in agency.txt
		--       all timezones must be equal; thus 1 feed_id always = 1 timezone
		--       irregardless of # of agenc(ies)
		select distinct agency.feed_id, tztodelta.seconds as tzutcdeltasecs
		from agency join tztodelta on agency.agency_timezone = tztodelta.timezone
	),
	timetable as (
		select
			cts.service_date,
			-- E.g. normalize from/to stop times in two ways:
			-- 1) normalize to the input date YYYYMMDD, so if a time departs at 02:00 on monday the following day;
			--    converted look like 26:00 on the previous day (since all times relative to input YYYYMMDD)
			-- 2) add the agency's associated timezone UTC delta value so that routing across agencies
			--    using different timezones functions correctly. All outuput values thus in UTC time
			--
			(cts.service_date - inputs.yyyymmdddate) * (60 * 60 * 24) + con.from_stop_time + tz.tzutcdeltasecs as from_stop_drutctime,
			(cts.service_date - inputs.yyyymmdddate) * (60 * 60 * 24) + con.to_stop_time + tz.tzutcdeltasecs as to_stop_drutctime,
			con.*
		from _cvcaltoservice cts
			join inputs on (
				-- E.g. optimization so we don't have to calculate {from,to}_stop_drutctime for *all*
				-- timetable entries (should handle both tz shifts & next day for schedule logic)
				cts.service_date between inputs.yyyymmdddate - 1 and inputs.yyyymmdddate + 1
			) and cts.feed_id in ({{ .FeedIDPlaceholders }})
			join {{ .Table }} con
				on cts.service_id = con.service_id and cts.feed_id = con.feed_id
				and from_stop_drutctime between seconds_from and seconds_to
			join feedidtotzutcdelta tz on con.feed_id = tz.feed_id
			order by from_stop_drutctime asc, con.from_stop_sequence asc
	)
	select {{ .Columns }} from timetable where 1 = 1
